/*
** Copyright (C) 2006 Thadeu Lima de Souza Cascardo <cascardo@minaslivre.org>
** Copyright (C) 2009 Thadeu Lima de Souza Cascardo <cascardo@holoscopio.com>
**  
** This program is free software; you can redistribute it and/or modify
** it under the terms of the GNU General Public License as published by
** the Free Software Foundation; either version 2 of the License, or
** (at your option) any later version.
**  
** This program is distributed in the hope that it will be useful,
** but WITHOUT ANY WARRANTY; without even the implied warranty of
** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
** GNU General Public License for more details.
**  
** You should have received a copy of the GNU General Public License
** along with this program; if not, write to the Free Software
** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
**  
*/

#include <gnutls/gnutls.h>
#include <gnet.h>
#include <glib.h>
#include <string.h>
#include <errno.h>
#include "ssl.h"

static void
ssl_connect (net_hook_t *hook)
{
}

static void
ssl_close (net_hook_t *hook)
{
  if (hook->peer)
    {
      hook->peer->peer = NULL;
      gnet_conn_disconnect (hook->peer->conn);
    }
  gnet_conn_delete (hook->conn);
  g_slice_free (net_hook_t, hook);
}

static void
ssl_write (net_hook_t *hook)
{
}

static void
ssl_read (net_hook_t *hook, gchar *buffer, size_t len)
{
  struct ssl_data *ssl = hook->peer->data;
  gnutls_record_send (ssl->session, buffer, len);
}

static void
ssl_error (net_hook_t *hook)
{
}

net_hook_t *
ssl_hook_new (GConn *conn, char *server, int port)
{
  net_hook_t *hook;
  hook = g_slice_new (net_hook_t);
  hook->conn = conn;
  hook->peer = NULL;
  hook->server = FALSE;
  hook->connect = ssl_connect;
  hook->close = ssl_close;
  hook->write = ssl_write;
  hook->read = ssl_read;
  hook->data = NULL;
  hook->peer = ssl_server_hook_new (hook, server, port);
  gnet_conn_set_callback (hook->conn, nethook_event, hook);
  return hook;
}

void
ssl_destroy (net_hook_t *hook)
{
  g_slice_free (net_hook_t, hook);
}
